import os

CWD = os.getcwd()

REDIS_LOCATION = 'unix://{0}/var/redis.sock?db=0'.format(CWD)

SECRET_KEY = "whatever"

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
    }
}

INSTALLED_APPS = (
    'django_cache_management',
    'django_nose'
)

CACHES = {
    'default': {
        "BACKEND": "django.core.cache.backends.locmem.LocMemCache"
    },
    'foo': {
        "BACKEND": "django.core.cache.backends.locmem.LocMemCache"
    }
}

TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

MIDDLEWARE_CLASSES = ()



from django.core.management.base import BaseCommand, CommandError
from django.core.cache import get_cache
from django.conf import settings

from optparse import make_option

class Command(BaseCommand):

    "Ping one or more caches."
    help = __doc__

    args = "[cache_name ...]"

    option_list = BaseCommand.option_list + (
        make_option('--all',
                    action='store_true',
                    dest='all',
                    default=False,
                    help='Ping all caches.'),
    )

    def handle(self, *args, **options):
        if options["all"]:
            if args:
                raise CommandError("cannot use --all with a cache name")

            args = sorted(settings.CACHES.keys())
        else:
            if not args:
                raise CommandError("specify at least one cache to ping")

            # Make sure all names given exist
            for name in args:
                get_cache(name)

        failed = False
        for name in args:
            cache = get_cache(name)
            try:
                "foo" in cache
            except:  # pylint: disable=bare-except
                result = "... unsuccessful"
                failed = True
            else:
                result = "... successful"
            self.stdout.write("Pinging " + name + result)

        if failed:
            raise CommandError("ping failed")



import json
import re

import six
from django.core.management.base import BaseCommand
from django.conf import settings

# json.dumps adds unnecessary white space before newlines. We use this
# regex to clean them.
clean_re = re.compile(r" +\n")

class Command(BaseCommand):

    """
    Lists the caches defined in your project's settings.

    .. warning:: This may expose SENSITIVE INFORMATION, like
    passwords.
    """

    help = __doc__

    def handle(self, *args, **options):
        for name, value in sorted(six.iteritems(settings.CACHES)):
            self.stdout.write("Cache named: " + name)
            # We use dumps to pretty-print the dictionary
            self.stdout.write(clean_re.sub(u"\n",
                                           json.dumps(value, indent=4)))
            self.stdout.write("")



from .normal import *

CACHES['nonexistent'] = {
    'BACKEND': 'django_redis.cache.RedisCache',
    'LOCATION': '/dev/null',
    'KEY_PREFIX': 'foo',
    'OPTIONS': {
        "CLIENT_CLASS": "django_redis.client.DefaultClient"
    }
}



from .normal import *
from six.moves import xrange

for index in xrange(1, 3):
    name = 'redis' + str(index)
    CACHES[name] = {
        'BACKEND': 'django_redis.cache.RedisCache',
        'LOCATION': REDIS_LOCATION,
        'KEY_PREFIX': name + '!',
        'OPTIONS': {
            "CLIENT_CLASS": "django_redis.client.DefaultClient"
        }
    }



import os

from setuptools import setup, find_packages
import sphinx
from sphinx.setup_command import BuildDoc
import sphinx.apidoc

version = open('VERSION').read().strip()
long_description = open("README.rst").read()

install_requires = [
    'Django>=1.6,<1.8',
    'django-nose>=1.3,<2',
    'django-redis>=3.8.1,<4',
    'six'
]

class Sphinx(BuildDoc):

    def run(self):
        src_dir = (self.distribution.package_dir or {'': ''})['']
        src_dir = os.path.join(os.getcwd(), src_dir)
        sphinx.apidoc.main(
            ['', '-f', '-o', os.path.join(self.source_dir, '_apidoc'),
             src_dir])
        BuildDoc.run(self)

setup(
    name="django-cache-management",
    version=version,
    packages=find_packages(),
    author="Louis-Dominique Dubeau",
    author_email="ldd@lddubeau.com",
    description="Cache management for Django.",
    long_description=long_description,
    license="MPL 2.0",
    keywords=["Django", "caching"],
    url="https://github.com/lddubeau/django-cache-management",
    install_requires=install_requires,
    # use_2to3=True,
    classifiers=[
        "Programming Language :: Python",
        #"Programming Language :: Python :: 3",
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)",
        "Operating System :: POSIX",
        "Framework :: Django",
        "Topic :: Software Development :: Libraries",
        "Topic :: Utilities",
    ],
    setup_requires=['sphinx'],
    cmdclass={'sphinx': Sphinx}
)



from django.core.management.base import BaseCommand, CommandError
from django.core.cache import get_cache
from django.conf import settings

from optparse import make_option

class Command(BaseCommand):

    """
Clear one or more cache.

Note that the clear operation is not guaranteed to be atomic.
    """
    help = __doc__

    args = "[cache_name ...]"

    option_list = BaseCommand.option_list + (
        make_option('--noop',
                    action='store_true',
                    dest='noop',
                    default=False,
                    help='Do not actually perform the action.'),
        make_option('--all',
                    action='store_true',
                    dest='all',
                    default=False,
                    help='Clear all caches.'),
        make_option('--method',
                    dest='method',
                    default="conservative",
                    choices=("conservative", "django-clear"),
                    help="""
The method to use. The method "conservative" will remove only the
keys that begin with the cache's prefix. The method "django-clear"
will use Django's ``clear`` method, which will delete even keys that are
not prefixed with the cache's key. "conservative" is the default.
""".strip()),
    )

    def handle(self, *args, **options):
        if options["all"]:
            if args:
                raise CommandError("cannot use --all with a cache name")

            args = settings.CACHES.keys()
        else:
            if not args:
                raise CommandError("specify at least one cache to clear")

            # Make sure all names given exist
            for name in args:
                get_cache(name)

        method = options["method"]
        noop = options["noop"]

        action = "Clearing " if not noop else "Not clearing "

        if method == "conservative":
            for name in args:
                config = settings.CACHES[name]
                backend = config["BACKEND"]
                failed = False
                if backend.startswith("django_redis."):
                    try:
                        import django_redis
                        django_redis.get_redis_connection(name)
                        # Yes, we grab all exceptions. It is up to the
                        # user to diagnose how their configuration is
                        # wrong.
                    except:  # pylint: disable=bare-except
                        failed = True
                else:
                    failed = True

                if failed:
                    raise CommandError(
                        "clearcache does not know how to "
                        "conservatively clear a "
                        "cache with backend {0}".format(backend))

            for name in args:
                self.stdout.write(action + name)
                config = settings.CACHES[name]
                cache = get_cache(name)
                prefix = cache.key_prefix
                backend = config["BACKEND"]
                if backend.startswith("django_redis."):
                    import django_redis
                    con = django_redis.get_redis_connection(name)
                    keys = con.keys(prefix + ':*')
                    if keys and not noop:
                        con.delete(*keys)
        else:
            for name in args:
                self.stdout.write(action + name)
                cache = get_cache(name)
                if not noop:
                    cache.clear()
